# seo-check-os-version

Development environment setting
# install PDM
# git clone ...
$ source .venv/bin/activate
$ pdm install
# $ vi ...
# TEST
$ pdm install
$ pdm test
$ pip install .

$ git add <FILE_NAME>
$ git commit -a
$ git push
$ git publish

USE

$ pip install cho-check-os-ver
$ python
>>> from cho_check_os_ver.hi  import hi
>>> hi()



# seo-check-os-version
